@@ -1,5 +1,5 @@
 """GraphQL endpoint for making queries to the Nautobot GraphQL endpoint."""
-from typing import Optional, Dict, Iterable, Any
+from typing import Optional, Dict, Any
 
 
 class GraphQLException(Exception):
