@@ -21,16 +21,18 @@ from pynautobot.core.endpoint import DetailEndpoint
 
 class IpAddresses(Record):
     def __str__(self):
-        return str(self.address)
+        parent_record_string = super().__str__()
+        return parent_record_string or str(self.address)
 
 
 class Prefixes(Record):
     def __str__(self):
-        return str(self.prefix)
+        parent_record_string = super().__str__()
+        return parent_record_string or str(self.prefix)
 
     @property
     def available_ips(self):
-        """ Represents the ``available-ips`` detail endpoint.
+        """Represents the ``available-ips`` detail endpoint.
 
         Returns a DetailEndpoint object that is the interface for
         viewing and creating IP addresses inside a prefix.
@@ -61,7 +63,7 @@ class Prefixes(Record):
 
     @property
     def available_prefixes(self):
-        """ Represents the ``available-prefixes`` detail endpoint.
+        """Represents the ``available-prefixes`` detail endpoint.
 
         Returns a DetailEndpoint object that is the interface for
         viewing and creating prefixes inside a parent prefix.
@@ -89,8 +91,3 @@ class Prefixes(Record):
 
         """
         return DetailEndpoint(self, "available-prefixes", custom_return=Prefixes)
-
-
-class Aggregates(Record):
-    def __str__(self):
-        return str(self.prefix)
